summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--state/state.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/state/state.go b/state/state.go
index 109e4d1..4bfbf39 100644
--- a/state/state.go
+++ b/state/state.go
@@ -12,8 +12,9 @@ type FeedResult struct {
// Contains the result of processing an Entry.
type EntryResult struct {
- EntryId string // Entry's identifier
- Err error // Set on error
+ EntryId string // Entry's identifier
+ EntryTitle string // Entry's title
+ Err error // Set on error
}
type ProcessState struct {